#
# spec file for package sioyek
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sioyek
Version:        2.0.0
Release:        6.5
Summary:        PDF Viewer for research papers and technical books
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://github.com/ahrm/sioyek
Source0:        https://github.com/ahrm/sioyek/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         no-link-gumbo.patch
Patch2:         https://github.com/ahrm/sioyek/pull/694.patch#/fix-sqlite-memory-leak.patch
Patch3:         https://git.alpinelinux.org/aports/plain/community/sioyek/mupdf-0.23.0.patch?id=86e913eccf19b97a16f25d9b6cdf0f50232f1226#/mupdf-0.23.0.patch
Patch4:         define-linux-standard-paths.patch
BuildRequires:  binutils
BuildRequires:  c++_compiler
BuildRequires:  libQt5Gui-devel
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libQt5OpenGLExtensions-devel-static
BuildRequires:  libqt5-qt3d-devel
BuildRequires:  libqt5-qt3d-tools
BuildRequires:  libqt5-qtbase
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  mupdf-devel-static
BuildRequires:  openjpeg2-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(jbig2dec)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(mujs)
BuildRequires:  pkgconfig(zlib)

%description
Sioyek is a PDF viewer designed for reading research papers and technical books.

%prep
%autosetup -p1

%build
# We really cannot use the qt5 macros here because the builds fail
# RPM build flags cannot really be used here also since they make the builds fail
%_libqt5_qmake "CONFIG+=non_portable" pdf_viewer_build_config.pro
%make_build

%install
# The install paths in the config file does not correspond to
# the usual paths of installation in openSUSE
mkdir -p %{buildroot}%{_datadir}/%{name}/shaders/
cp -v pdf_viewer/shaders/* %{buildroot}%{_datadir}/%{name}/shaders/

install -Dm755 %{name} -t "%{buildroot}%{_bindir}/"

install -Dm644 pdf_viewer/prefs.config -t "%{buildroot}%{_sysconfdir}/%{name}/"
install -Dm644 pdf_viewer/keys.config -t "%{buildroot}%{_sysconfdir}/%{name}/"
install -Dm644 resources/%{name}-icon-linux.png -t "%{buildroot}%{_datadir}/pixmaps/"
install -Dm644 resources/%{name}.desktop -t "%{buildroot}%{_datadir}/applications/"
install -Dm644 resources/%{name}.1 -t "%{buildroot}%{_mandir}/man1/"
install -Dm644 tutorial.pdf -t "%{buildroot}%{_datadir}/%{name}/"

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}

%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_datadir}/pixmaps/%{name}-icon-linux.png

%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/prefs.config
%config(noreplace) %{_sysconfdir}/%{name}/keys.config

%license LICENSE
%doc README.md

%changelog
* Fri Nov  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove move of config files to /usr/etc. Sioyek never has code to
  read configs in that directory.
* Fri Nov  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- add config as well to /etc. seems to break things if not
* Fri Nov  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- add patch define-linux-standard-paths.patch. using `sed` is very brittle to use
- add env var CONFIG+=non_portable
- move config files from /etc to /usr/etc
* Tue Oct  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Fix mupdf incompatibility errors by adding mupdf-0.23.0.patch
* Tue Oct  3 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add fix-sqlite-memory-leak.patch.
* Thu Aug 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Attempt to fix sioyek build. Resolves bsc#1209453.
* Tue Mar  7 2023 Jan Engelhardt <jengelh@inai.de>
- Add no-link-gumbo.patch and drop dependency on gumbo.
* Mon Jan  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix icon not showing by moving back the icon from
  `/usr/share/icons` to `/usr/share/pixmaps`.
* Mon Dec 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix icon path.
* Sun Dec 18 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 2.0.0:
  * added super_fast_search
  * added scrolling between pages in overview window
  * added search results in overview window
  * added overview_to_portal
  * added the ability to define your own macros in prefs_user.config
  * added the ability to source other configs from different paths
  * improved the official python module for sioyek for extensions
  * upgrade to MuPDF 1.20
  * New keybind parsing method with support for non-standard layouts and unicode
    characters
  * Add a smooth scroll mode.
  * Add ability to select single words using keyboard_select command
  * Add a scrollbar which can be enabled using toggle_scrollbar command
  * Add commands to set configuration options at runtime.
  * Add prerendered_page_count option which allows to configure how many pages
    does sioyek prerender
  * Add an option to show the closest bookmark in the statusbar
  * Add an option to indicate whether we are close to a portal in the statusbar
  * Add an option to highlight using middle click instead of pressing a button. See
    https://github.com/ahrm/sioyek/commit/7390a40dec98b829c8beacd5d3997b00d2072ec7.
  * Add ability to specify colors in config files using hexadecimal strings.
    For example instead of 1 1 0 you can now use #ffff00.
  * Many bug-fixes and quality of life improvements
- Remove patchsets:
  * 0000-mupdf-1.20-compat-issue.patch
  * 0001-parse-mupdf-1.20-links.patch
  * 0002-improve-xdg-desktop-entry.patch
  * 0002-fix-desktop-file-error.patch
  * 0002-improve-desktop-file.patch
* Wed Dec 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- icon is moved to `/usr/share/pixmaps`. this is to show the desktop
  entry correctly
* Mon Nov 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0002-improve-xdg-desktop-entry.patch and 0002-fix-desktop-file-error.patch
* Mon Nov 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add 0002-improve-desktop-file.patch
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove strip for debuginfo creation
* Thu Nov 24 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for sioyek 1.5.0
- Add 0000-mupdf-1.20-compat-issue.patch
- Add 0001-parse-mupdf-1.20-links.patch
- Add sioyek-1.5.0.tar.gz
